@@ -31,7 +31,7 @@ test_that("Interval", {
   expect_equal(i$contains(list(Tuple$new(1, 4), Tuple$new(1, 3), Tuple$new(3, 1))), c(TRUE, TRUE, FALSE))
   expect_equal(
     (Interval$new(1, 2) * ConditionalSet$new(function(x) TRUE))$strprint(),
-    "[1,2] X {x in V : TRUE}"
+    "[1,2] X {x in V}"
   )
   expect_equal(Interval$new(1, 2) * Set$new(), Interval$new(1, 2))
   useUnicode(TRUE)
@@ -53,7 +53,7 @@ test_that("fuzzy", {
   expect_equal(FuzzySet$new() * FuzzySet$new(1, 0.2), FuzzySet$new(1, 0.2))
   expect_equal(
     (FuzzySet$new(1, 0.5) * ConditionalSet$new(function(x) TRUE))$strprint(),
-    "{1(0.5)} X {x in V : TRUE}"
+    "{1(0.5)} X {x in V}"
   )
   expect_true(setproduct(FuzzySet$new(1, 0.1), FuzzySet$new(2, 0.2), simplify = TRUE)$equals(Set$new(FuzzyTuple$new(1, 0.1, 2, 0.2))))
   expect_equal(
